""" Isobaric or near isobaric substitution options.
"""

ISOBARIC_SINGLES = {
    'R': ['GV', 'VG'],
    'N': ['GG'],
    'D': ['n'],
    'E': ['q'],
    'Q': ['K', 'AG', 'GA'],
    'K': ['Q', 'AG', 'GA'],
    'F': ['m'],
    'W': ['AD', 'An', 'DA', 'EG', 'GE', 'Gq', 'SV', 'VS', 'nA', 'qG'],
    'm': ['F'],
    'c': ['CG', 'GC'],
    'n': ['D'],
    'q': ['E'],
}

ISOBARIC_DOUBLETS = {
    'AR': ['RA', 'NL', 'QV', 'LN', 'KV', 'VQ', 'VK'],
    'AN': ['NA', 'QG', 'GQ', 'GK', 'KG'],
    'AD': ['W', 'DA', 'EG', 'GE', 'Gq', 'SV', 'VS', 'nA', 'qG'],
    'AC': ['CA', 'SS'],
    'AE': ['CP', 'EA', 'LS', 'PC', 'SL', 'TV', 'VT', 'qA'],
    'AQ': ['QA', 'KA'],
    'AG': ['Q', 'K', 'GA'],
    'AH': ['HA'],
    'AL': ['LA', 'PS', 'SP'],
    'AK': ['QA', 'KA'],
    'AM': ['DS', 'CV', 'MA', 'SD', 'Sn', 'TT', 'VC', 'nS'],
    'AF': ['MS', 'FA', 'SM', 'mA'],
    'AP': ['PA'],
    'AS': ['GT', 'SA', 'TG'],
    'AT': ['DG', 'GD', 'Gn', 'TA', 'nG'],
    'AW': ['RT', 'EQ', 'EK', 'QE', 'Qq', 'KE', 'Kq', 'Pc', 'TR', 'WA', 'cP', 'qQ', 'qK'],
    'AY': ['HP', 'FS', 'PH', 'SF', 'Sm', 'YA', 'mS'],
    'AV': ['GL', 'LG', 'VA'],
    'Am': ['DC', 'CD', 'Cn', 'MS', 'FA', 'SM', 'mA', 'nC'],
    'Ac': ['CQ', 'CK', 'QC', 'KC', 'cA'],
    'An': ['W', 'DA', 'EG', 'GE', 'Gq', 'SV', 'VS', 'nA', 'qG'],
    'Aq': ['CP', 'EA', 'LS', 'PC', 'SL', 'TV', 'VT', 'qA'],
    'RA': ['AR', 'NL', 'QV', 'LN', 'KV', 'VQ', 'VK'],
    'RN': ['NR'],
    'RD': ['DR', 'nR'],
    'RC': ['CR', 'QM', 'KM', 'MQ', 'MK', 'Vc', 'cV'],
    'RE': ['ER', 'WV', 'VW', 'qR'],
    'RQ': ['QR', 'HF', 'KR', 'FH'],
    'RG': ['NV', 'GR', 'VN'],
    'RH': ['HR'],
    'RL': ['LR'],
    'RK': ['QR', 'KR'],
    'RM': ['MR', 'TW', 'WT'],
    'RF': ['FR', 'mR'],
    'RP': ['PR'],
    'RS': [
        'NE', 'Nq', 'DQ', 'DK', 'EN', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'WG', 'nQ', 'nK', 'qN'
    ],
    'RT': ['AW', 'EQ', 'EK', 'QE', 'Qq', 'KE', 'Kq', 'TR', 'WA', 'qQ', 'qK'],
    'RW': ['WR'],
    'RY': ['YR'],
    'RV': ['VR'],
    'Rm': ['FR', 'mR'],
    'Rc': ['cR'],
    'Rn': ['DR', 'nR'],
    'Rq': ['ER', 'WV', 'VW', 'qR'],
    'NA': ['AN', 'QG', 'GQ', 'GK', 'KG'],
    'NR': ['RN'],
    'NN': ['DL', 'EV', 'LD', 'Ln', 'MP', 'PM', 'VE', 'Vq', 'nL', 'qV'],
    'ND': ['DN', 'QT', 'TQ', 'nN'],
    'NC': ['CN', 'Gc', 'cG'],
    'NE': ['RS', 'DQ', 'DK', 'EN', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'WG', 'nQ', 'nK', 'qN'],
    'NQ': ['EL', 'QN', 'LE', 'Lq', 'KN', 'qL'],
    'NG': ['GN'],
    'NH': ['HN'],
    'NL': ['AR', 'RA', 'QV', 'LN', 'KV', 'VQ', 'VK'],
    'NK': ['EL', 'QN', 'LE', 'Lq', 'KN', 'qL'],
    'NM': ['MN'],
    'NF': ['FN', 'Tc', 'mN', 'cT'],
    'NP': ['PN'],
    'NS': ['SN'],
    'NT': ['QS', 'KS', 'SQ', 'SK', 'TN'],
    'NW': ['HY', 'WN', 'YH'],
    'NY': ['YN'],
    'NV': ['RG', 'GR', 'VN'],
    'Nm': ['FN', 'Tc', 'mN', 'cT'],
    'Nc': ['HH', 'cN'],
    'Nn': ['DN', 'QT', 'TQ', 'nN'],
    'Nq': ['RS', 'DQ', 'DK', 'EN', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'WG', 'nQ', 'nK', 'qN'],
    'DA': ['W', 'AD', 'An', 'EG', 'GE', 'Gq', 'SV', 'VS', 'qG'],
    'DR': ['RD', 'Rn'],
    'DN': ['ND', 'Nn', 'QT', 'TQ'],
    'DD': ['ET', 'TE', 'Tq', 'nn', 'qT'],
    'DC': ['Am', 'CD', 'Cn', 'MS', 'SM', 'mA'],
    'DE': ['ED', 'En', 'Pm', 'mP', 'nq', 'qD', 'qn'],
    'DQ': ['RS', 'NE', 'Nq', 'EN', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'WG', 'nK', 'qN'],
    'DG': ['AT', 'GD', 'Gn', 'TA'],
    'DH': ['HD', 'Hn'],
    'DL': ['NN', 'EV', 'LD', 'Ln', 'MP', 'PM', 'VE', 'Vq', 'qV'],
    'DK': ['RS', 'NE', 'Nq', 'EN', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'WG', 'nQ', 'qN'],
    'DM': ['MD', 'Mn', 'Vm', 'mV'],
    'DF': ['MM', 'FD', 'Fn', 'YV', 'VY', 'mD', 'mn', 'nm'],
    'DP': ['PD', 'Pn'],
    'DS': ['AM', 'CV', 'MA', 'SD', 'Sn', 'TT', 'VC'],
    'DT': ['CL', 'ES', 'LC', 'SE', 'Sq', 'TD', 'Tn', 'qS'],
    'DW': ['WD', 'Wn'],
    'DY': ['MF', 'Mm', 'FM', 'YD', 'Yn', 'mM'],
    'DV': ['LT', 'TL', 'VD', 'Vn'],
    'Dm': ['MM', 'FD', 'Fn', 'mD', 'mn', 'nF'],
    'Dc': ['Qm', 'mQ', 'cD', 'cn'],
    'Dn': ['ET', 'TE', 'Tq', 'nD', 'qT'],
    'Dq': ['ED', 'En', 'Pm', 'mP', 'nE', 'qD', 'qn'],
    'CA': ['AC', 'SS'],
    'CR': ['RC', 'QM', 'KM', 'MQ', 'MK', 'Vc', 'cV'],
    'CN': ['NC', 'Gc', 'cG'],
    'CD': ['Am', 'DC', 'MS', 'SM', 'mA', 'nC'],
    'CE': ['EC', 'MT', 'TM', 'qC'],
    'CQ': ['Ac', 'QC', 'KC', 'cA'],
    'CG': ['c', 'GC'],
    'CH': ['HC'],
    'CL': ['DT', 'ES', 'LC', 'SE', 'Sq', 'TD', 'Tn', 'nT', 'qS'],
    'CK': ['Ac', 'QC', 'KC', 'cA'],
    'CM': ['MC', 'Sm', 'mS'],
    'CF': ['FC', 'SY', 'YS', 'mC'],
    'CP': ['AE', 'Aq', 'EA', 'PC', 'qA'],
    'CS': ['SC'],
    'CT': ['GF', 'Gm', 'FG', 'TC', 'mG'],
    'CW': ['Ec', 'WC', 'cE', 'cq', 'qc'],
    'CY': ['EH', 'HE', 'Hq', 'YC', 'qH'],
    'CV': ['AM', 'DS', 'MA', 'SD', 'Sn', 'TT', 'VC', 'nS'],
    'Cm': ['FC', 'mC'],
    'Cc': ['cC'],
    'Cn': ['Am', 'DC', 'MS', 'SM', 'mA', 'nC'],
    'Cq': ['EC', 'MT', 'TM', 'qC'],
    'EA': ['AE', 'Aq', 'CP', 'LS', 'PC', 'SL', 'TV', 'VT'],
    'ER': ['RE', 'Rq', 'WV', 'VW'],
    'EN': ['RS', 'NE', 'Nq', 'DQ', 'DK', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'WG', 'nQ', 'nK'],
    'ED': ['DE', 'Dq', 'Pm', 'mP', 'nE', 'nq', 'qn'],
    'EC': ['CE', 'Cq', 'MT', 'TM'],
    'EE': ['qq'],
    'EQ': ['AW', 'RT', 'QE', 'Qq', 'KE', 'Kq', 'Pc', 'TR', 'WA', 'cP', 'qK'],
    'EG': ['W', 'AD', 'An', 'DA', 'GE', 'Gq', 'SV', 'VS', 'nA'],
    'EH': ['CY', 'HE', 'Hq', 'YC'],
    'EL': ['NQ', 'NK', 'QN', 'LE', 'Lq', 'KN'],
    'EK': ['AW', 'RT', 'QE', 'Qq', 'KE', 'Kq', 'TR', 'WA', 'qQ'],
    'EM': ['Lm', 'ME', 'Mq', 'PY', 'YP', 'mL'],
    'EF': ['LY', 'FE', 'Fq', 'YL', 'mE', 'mq', 'qm'],
    'EP': ['PE', 'Pq'],
    'ES': ['DT', 'CL', 'LC', 'SE', 'Sq', 'TD', 'Tn', 'nT'],
    'ET': ['DD', 'Dn', 'MV', 'TE', 'Tq', 'VM', 'nD', 'nn'],
    'EW': ['WE', 'Wq'],
    'EY': ['YE', 'Yq'],
    'EV': ['NN', 'DL', 'LD', 'Ln', 'MP', 'PM', 'VE', 'Vq', 'nL'],
    'Em': ['FE', 'Fq', 'mE', 'mq', 'qF'],
    'Ec': ['CW', 'WC', 'cE', 'cq'],
    'En': ['DE', 'Dq', 'Pm', 'mP', 'nE', 'nq', 'qD'],
    'Eq': ['qE'],
    'QA': ['AQ', 'AK'],
    'QR': ['RQ', 'RK', 'HF', 'FH'],
    'QN': ['NQ', 'NK', 'EL', 'LE', 'Lq', 'qL'],
    'QD': ['RS', 'NE', 'Nq', 'DQ', 'DK', 'EN', 'GW', 'Kn', 'SR', 'WG', 'nQ', 'nK', 'qN'],
    'QC': ['Ac', 'CQ', 'CK', 'cA'],
    'QE': ['AW', 'RT', 'EQ', 'EK', 'Kq', 'Pc', 'TR', 'WA', 'cP', 'qQ', 'qK'],
    'QG': ['AN', 'NA', 'GQ', 'GK'],
    'QH': ['HQ', 'HK'],
    'QL': ['LQ', 'LK'],
    'QK': ['KQ'],
    'QM': ['RC', 'CR', 'MQ', 'MK', 'Vc', 'cV'],
    'QF': ['Km', 'FQ', 'FK', 'mQ', 'mK'],
    'QP': ['PQ', 'PK'],
    'QS': ['NT', 'SQ', 'SK', 'TN'],
    'QT': ['ND', 'Nn', 'DN', 'TQ', 'TK', 'nN'],
    'QW': ['WQ', 'WK'],
    'QY': ['YQ', 'YK'],
    'QV': ['AR', 'RA', 'NL', 'LN', 'VQ', 'VK'],
    'Qm': ['Dc', 'FQ', 'mQ', 'mK', 'cD', 'cn', 'nc'],
    'Qc': ['cQ', 'cK'],
    'Qn': ['RS', 'NE', 'Nq', 'DQ', 'DK', 'EN', 'GW', 'KD', 'SR', 'WG', 'nQ', 'nK', 'qN'],
    'Qq': ['AW', 'RT', 'EQ', 'EK', 'KE', 'Pc', 'TR', 'WA', 'cP', 'qQ', 'qK'],
    'GA': ['Q', 'K', 'AG'],
    'GR': ['RG', 'NV', 'VN'],
    'GN': ['NG'],
    'GD': ['AT', 'DG', 'TA', 'nG'],
    'GC': ['c', 'CG'],
    'GE': ['W', 'AD', 'An', 'DA', 'EG', 'SV', 'VS', 'nA', 'qG'],
    'GQ': ['AN', 'NA', 'QG', 'KG'],
    'GG': ['N'],
    'GH': ['HG', 'PP'],
    'GL': ['AV', 'LG', 'VA'],
    'GK': ['AN', 'NA', 'QG', 'KG'],
    'GM': ['MG', 'ST', 'TS'],
    'GF': ['CT', 'FG', 'TC', 'mG'],
    'GP': ['PG'],
    'GS': ['SG'],
    'GT': ['AS', 'SA', 'TG'],
    'GW': [
        'RS', 'NE', 'Nq', 'DQ', 'DK', 'EN', 'QD', 'Qn', 'KD', 'Kn', 'SR', 'WG', 'nQ', 'nK', 'qN',
    ],
    'GY': ['YG'],
    'GV': ['R', 'VG'],
    'Gm': ['CT', 'FG', 'TC', 'mG'],
    'Gc': ['NC', 'CN', 'cG'],
    'Gn': ['AT', 'DG', 'TA', 'nG'],
    'Gq': ['W', 'AD', 'An', 'DA', 'EG', 'SV', 'VS', 'nA', 'qG'],
    'HA': ['AH'],
    'HR': ['RH'],
    'HN': ['NH'],
    'HD': ['DH', 'nH'],
    'HC': ['CH'],
    'HE': ['CY', 'EH', 'YC', 'qH'],
    'HQ': ['QH', 'KH'],
    'HG': ['GH', 'PP'],
    'HH': ['Nc', 'cN'],
    'HL': ['LH', 'SY', 'YS'],
    'HK': ['QH', 'KH'],
    'HM': ['MH'],
    'HF': ['RQ', 'QR', 'FH', 'mH'],
    'HP': ['AY', 'FS', 'PH', 'SF', 'Sm', 'YA', 'mS'],
    'HS': ['SH'],
    'HT': ['TH'],
    'HW': ['WH', 'Yc', 'cY'],
    'HY': ['NW', 'WN', 'YH'],
    'HV': ['VH'],
    'Hm': ['FH', 'mH'],
    'Hc': ['cH'],
    'Hn': ['DH', 'nH'],
    'Hq': ['CY', 'EH', 'YC', 'qH'],
    'LA': ['AL', 'PS', 'SP'],
    'LR': ['RL'],
    'LN': ['AR', 'RA', 'NL', 'QV', 'KV', 'VQ', 'VK'],
    'LD': ['NN', 'DL', 'EV', 'MP', 'PM', 'VE', 'Vq', 'nL', 'qV'],
    'LC': ['DT', 'CL', 'ES', 'SE', 'Sq', 'TD', 'Tn', 'nT', 'qS'],
    'LE': ['NQ', 'NK', 'EL', 'QN', 'KN', 'qL'],
    'LQ': ['QL', 'KL'],
    'LG': ['AV', 'GL', 'VA'],
    'LH': ['HL', 'SY', 'YS'],
    'LK': ['QL', 'KL'],
    'LM': ['ML', 'FP', 'PF', 'Pm', 'mP'],
    'LF': ['FL', 'PY', 'YP', 'mL'],
    'LP': ['PL'],
    'LS': ['AE', 'Aq', 'EA', 'SL', 'TV', 'VT', 'qA'],
    'LT': ['DV', 'TL', 'VD', 'Vn', 'nV'],
    'LW': ['WL'],
    'LY': ['EF', 'FE', 'Fq', 'YL', 'qF'],
    'LV': ['VL'],
    'Lm': ['EM', 'ME', 'Mq', 'FL', 'PY', 'YP', 'mL', 'qM'],
    'Lc': ['SW', 'WS', 'cL'],
    'Ln': ['NN', 'DL', 'EV', 'MP', 'PM', 'VE', 'Vq', 'nL', 'qV'],
    'Lq': ['NQ', 'NK', 'EL', 'QN', 'KN', 'qL'],
    'KA': ['AQ', 'AK'],
    'KR': ['RQ', 'RK'],
    'KN': ['NQ', 'NK', 'EL', 'LE', 'Lq', 'qL'],
    'KD': ['RS', 'NE', 'Nq', 'DQ', 'DK', 'EN', 'Qn', 'GW', 'SR', 'WG', 'nQ', 'nK', 'qN'],
    'KC': ['Ac', 'CQ', 'CK', 'cA'],
    'KE': ['AW', 'RT', 'EQ', 'EK', 'Qq', 'TR', 'WA', 'qQ', 'qK'],
    'KQ': ['QK'],
    'KG': ['AN', 'NA', 'GQ', 'GK'],
    'KH': ['HQ', 'HK'],
    'KL': ['LQ', 'LK'],
    'KM': ['RC', 'CR', 'MQ', 'MK', 'Vc', 'cV'],
    'KF': ['FQ', 'FK', 'mK'],
    'KP': ['PQ', 'PK'],
    'KS': ['NT', 'SQ', 'SK', 'TN'],
    'KT': ['TQ', 'TK'],
    'KW': ['WQ', 'WK'],
    'KY': ['YQ', 'YK'],
    'KV': ['AR', 'RA', 'NL', 'LN', 'VQ', 'VK'],
    'Km': ['QF', 'FQ', 'FK', 'mQ', 'mK'],
    'Kc': ['cQ', 'cK'],
    'Kn': ['RS', 'NE', 'Nq', 'DQ', 'DK', 'EN', 'QD', 'GW', 'SR', 'WG', 'nQ', 'nK', 'qN'],
    'Kq': ['AW', 'RT', 'EQ', 'EK', 'QE', 'TR', 'WA', 'qQ', 'qK'],
    'MA': ['AM', 'DS', 'CV', 'SD', 'Sn', 'TT', 'VC', 'nS'],
    'MR': ['RM', 'TW', 'WT'],
    'MN': ['NM'],
    'MD': ['DM', 'Vm', 'mV', 'nM'],
    'MC': ['CM', 'Sm', 'mS'],
    'ME': ['EM', 'Lm', 'PY', 'YP', 'mL', 'qM'],
    'MQ': ['RC', 'CR', 'QM', 'KM', 'Vc', 'cV'],
    'MG': ['GM', 'ST', 'TS'],
    'MH': ['HM'],
    'ML': ['LM', 'FP', 'PF', 'Pm', 'mP'],
    'MK': ['RC', 'CR', 'QM', 'KM', 'Vc', 'cV'],
    'MM': ['DF', 'Dm', 'FD', 'Fn', 'mD', 'mn', 'nF', 'nm'],
    'MF': ['DY', 'FM', 'YD', 'Yn', 'mM', 'nY'],
    'MP': ['NN', 'DL', 'EV', 'LD', 'Ln', 'PM', 'VE', 'Vq', 'nL', 'qV'],
    'MS': ['AF', 'Am', 'DC', 'CD', 'Cn', 'FA', 'SM', 'mA', 'nC'],
    'MT': ['CE', 'Cq', 'EC', 'TM', 'qC'],
    'MW': ['WM'],
    'MY': ['FF', 'Fm', 'YM', 'mF', 'mm'],
    'MV': ['ET', 'TE', 'Tq', 'VM', 'qT'],
    'Mm': ['DY', 'FM', 'YD', 'Yn', 'mM', 'nY'],
    'Mc': ['cM'],
    'Mn': ['DM', 'Vm', 'mV', 'nM'],
    'Mq': ['EM', 'Lm', 'PY', 'YP', 'mL', 'qM'],
    'FA': ['AF', 'Am', 'MS', 'SM'],
    'FR': ['RF', 'Rm'],
    'FN': ['NF', 'Nm', 'Tc', 'cT'],
    'FD': ['DF', 'Dm', 'MM', 'YV', 'VY', 'mn', 'nF', 'nm'],
    'FC': ['CF', 'Cm', 'SY', 'YS'],
    'FE': ['EF', 'Em', 'LY', 'YL', 'mq', 'qF', 'qm'],
    'FQ': ['QF', 'Qm', 'KF', 'Km', 'mK'],
    'FG': ['CT', 'GF', 'Gm', 'TC'],
    'FH': ['RQ', 'QR', 'HF', 'Hm'],
    'FL': ['LF', 'Lm', 'PY', 'YP'],
    'FK': ['QF', 'KF', 'Km'],
    'FM': ['DY', 'MF', 'Mm', 'YD', 'Yn', 'nY'],
    'FF': ['MY', 'YM'],
    'FP': ['LM', 'ML', 'PF', 'Pm'],
    'FS': ['AY', 'HP', 'PH', 'SF', 'Sm', 'YA'],
    'FT': ['TF', 'Tm'],
    'FW': ['WF', 'Wm'],
    'FY': ['YF', 'Ym'],
    'FV': ['VF', 'Vm'],
    'Fm': ['MY', 'YM', 'mF'],
    'Fc': ['cF', 'cm'],
    'Fn': ['DF', 'Dm', 'MM', 'YV', 'VY', 'mD', 'nF', 'nm'],
    'Fq': ['EF', 'Em', 'LY', 'YL', 'mE', 'qF', 'qm'],
    'PA': ['AP'],
    'PR': ['RP'],
    'PN': ['NP'],
    'PD': ['DP', 'nP'],
    'PC': ['AE', 'Aq', 'CP', 'EA', 'qA'],
    'PE': ['EP', 'qP'],
    'PQ': ['QP', 'KP'],
    'PG': ['GP'],
    'PH': ['AY', 'HP', 'FS', 'SF', 'Sm', 'YA', 'mS'],
    'PL': ['LP'],
    'PK': ['QP', 'KP'],
    'PM': ['NN', 'DL', 'EV', 'LD', 'Ln', 'MP', 'VE', 'Vq', 'nL', 'qV'],
    'PF': ['LM', 'ML', 'FP', 'mP'],
    'PP': ['GH', 'HG'],
    'PS': ['AL', 'LA', 'SP'],
    'PT': ['TP', 'VV'],
    'PW': ['WP'],
    'PY': ['EM', 'LF', 'Lm', 'ME', 'Mq', 'FL', 'YP', 'mL', 'qM'],
    'PV': ['VP'],
    'Pm': ['DE', 'Dq', 'ED', 'En', 'LM', 'ML', 'FP', 'mP', 'nE', 'nq', 'qD', 'qn'],
    'Pc': ['AW', 'EQ', 'QE', 'Qq', 'WA', 'cP', 'qQ'],
    'Pn': ['DP', 'nP'],
    'Pq': ['EP', 'qP'],
    'SA': ['AS', 'GT', 'TG'],
    'SR': [
        'RS', 'NE', 'Nq', 'DQ', 'DK', 'EN', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'WG', 'nQ', 'nK', 'qN',
    ],
    'SN': ['NS'],
    'SD': ['AM', 'DS', 'CV', 'MA', 'TT', 'VC', 'nS'],
    'SC': ['CS'],
    'SE': ['DT', 'CL', 'ES', 'LC', 'TD', 'Tn', 'nT', 'qS'],
    'SQ': ['NT', 'QS', 'KS', 'TN'],
    'SG': ['GS'],
    'SH': ['HS'],
    'SL': ['AE', 'Aq', 'EA', 'LS', 'TV', 'VT', 'qA'],
    'SK': ['NT', 'QS', 'KS', 'TN'],
    'SM': ['AF', 'Am', 'DC', 'CD', 'Cn', 'MS', 'FA', 'mA', 'nC'],
    'SF': ['AY', 'HP', 'FS', 'PH', 'YA', 'mS'],
    'SP': ['AL', 'LA', 'PS'],
    'SS': ['AC', 'CA'],
    'ST': ['GM', 'MG', 'TS'],
    'SW': ['Lc', 'WS', 'cL'],
    'SY': ['CF', 'HL', 'LH', 'FC', 'YS'],
    'SV': ['W', 'AD', 'An', 'DA', 'EG', 'GE', 'Gq', 'VS', 'nA', 'qG'],
    'Sm': ['AY', 'CM', 'HP', 'MC', 'FS', 'PH', 'YA', 'mS'],
    'Sc': ['cS'],
    'Sn': ['AM', 'DS', 'CV', 'MA', 'TT', 'VC', 'nS'],
    'Sq': ['DT', 'CL', 'ES', 'LC', 'TD', 'Tn', 'nT', 'qS'],
    'TA': ['AT', 'DG', 'GD', 'Gn', 'nG'],
    'TR': ['AW', 'RT', 'EQ', 'EK', 'QE', 'Qq', 'KE', 'Kq', 'WA', 'qQ', 'qK'],
    'TN': ['NT', 'QS', 'KS', 'SQ', 'SK'],
    'TD': ['DT', 'CL', 'ES', 'LC', 'SE', 'Sq', 'nT', 'qS'],
    'TC': ['CT', 'GF', 'Gm', 'FG', 'mG'],
    'TE': ['DD', 'Dn', 'ET', 'MV', 'VM', 'nD', 'nn', 'qT'],
    'TQ': ['ND', 'Nn', 'DN', 'QT', 'KT', 'nN'],
    'TG': ['AS', 'GT', 'SA'],
    'TH': ['HT'],
    'TL': ['DV', 'LT', 'VD', 'Vn', 'nV'],
    'TK': ['QT', 'KT'],
    'TM': ['CE', 'Cq', 'EC', 'MT', 'qC'],
    'TF': ['FT', 'mT'],
    'TP': ['PT', 'VV'],
    'TS': ['GM', 'MG', 'ST'],
    'TT': ['AM', 'DS', 'CV', 'MA', 'SD', 'Sn', 'VC', 'nS'],
    'TW': ['RM', 'MR', 'WT'],
    'TY': ['YT'],
    'TV': ['AE', 'Aq', 'EA', 'LS', 'SL', 'VT', 'qA'],
    'Tm': ['FT', 'mT'],
    'Tc': ['NF', 'Nm', 'FN', 'mN', 'cT'],
    'Tn': ['DT', 'CL', 'ES', 'LC', 'SE', 'Sq', 'nT', 'qS'],
    'Tq': ['DD', 'Dn', 'ET', 'MV', 'VM', 'nD', 'nn', 'qT'],
    'WA': ['AW', 'RT', 'EQ', 'EK', 'QE', 'Qq', 'KE', 'Kq', 'Pc', 'TR', 'cP', 'qQ', 'qK'],
    'WR': ['RW'],
    'WN': ['NW', 'HY', 'YH'],
    'WD': ['DW', 'nW'],
    'WC': ['CW', 'Ec', 'cE', 'cq', 'qc'],
    'WE': ['EW', 'qW'],
    'WQ': ['QW', 'KW'],
    'WG': [
        'RS', 'NE', 'Nq', 'DQ', 'DK', 'EN', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'nQ', 'nK', 'qN',
    ],
    'WH': ['HW', 'Yc', 'cY'],
    'WL': ['LW'],
    'WK': ['QW', 'KW'],
    'WM': ['MW'],
    'WF': ['FW', 'mW'],
    'WP': ['PW'],
    'WS': ['Lc', 'SW', 'cL'],
    'WT': ['RM', 'MR', 'TW'],
    'WY': ['YW'],
    'WV': ['RE', 'Rq', 'ER', 'VW', 'qR'],
    'Wm': ['FW', 'mW'],
    'Wc': ['cW'],
    'Wn': ['DW', 'nW'],
    'Wq': ['EW', 'qW'],
    'YA': ['AY', 'HP', 'FS', 'PH', 'SF', 'Sm', 'mS'],
    'YR': ['RY'],
    'YN': ['NY'],
    'YD': ['DY', 'MF', 'Mm', 'FM', 'mM', 'nY'],
    'YC': ['CY', 'EH', 'HE', 'Hq', 'qH'],
    'YE': ['EY', 'qY'],
    'YQ': ['QY', 'KY'],
    'YG': ['GY'],
    'YH': ['NW', 'HY', 'WN'],
    'YL': ['EF', 'LY', 'FE', 'Fq', 'qF'],
    'YK': ['QY', 'KY'],
    'YM': ['MY', 'FF', 'Fm', 'mF', 'mm'],
    'YF': ['FY', 'mY'],
    'YP': ['EM', 'LF', 'Lm', 'ME', 'Mq', 'FL', 'PY', 'mL', 'qM'],
    'YS': ['CF', 'HL', 'LH', 'FC', 'SY'],
    'YT': ['TY'],
    'YW': ['WY'],
    'YV': ['DF', 'FD', 'Fn', 'VY', 'nF'],
    'Ym': ['FY', 'mY'],
    'Yc': ['HW', 'yT', 'WH', 'Ty', 'cY'],
    'Yn': ['DY', 'MF', 'Mm', 'FM', 'mM', 'nY'],
    'Yq': ['EY', 'qY'],
    'VA': ['AV', 'GL', 'LG'],
    'VR': ['RV'],
    'VN': ['RG', 'NV', 'GR'],
    'VD': ['DV', 'LT', 'TL', 'nV'],
    'VC': ['AM', 'DS', 'CV', 'MA', 'SD', 'Sn', 'TT', 'nS'],
    'VE': ['NN', 'DL', 'EV', 'LD', 'Ln', 'MP', 'PM', 'nL', 'qV'],
    'VQ': ['AR', 'RA', 'NL', 'QV', 'LN', 'KV'],
    'VG': ['R', 'GV'],
    'VH': ['HV'],
    'VL': ['LV'],
    'VK': ['AR', 'RA', 'NL', 'QV', 'LN', 'KV'],
    'VM': ['ET', 'MV', 'TE', 'Tq', 'qT'],
    'VF': ['FV', 'mV'],
    'VP': ['PV'],
    'VS': ['W', 'AD', 'An', 'DA', 'EG', 'GE', 'Gq', 'SV', 'nA', 'qG'],
    'VT': ['AE', 'Aq', 'EA', 'LS', 'SL', 'TV', 'qA'],
    'VW': ['RE', 'Rq', 'ER', 'WV', 'qR'],
    'VY': ['DF', 'FD', 'Fn', 'YV', 'nF'],
    'VV': ['PT', 'TP'],
    'Vm': ['DM', 'MD', 'Mn', 'FV', 'mV', 'nM'],
    'Vc': ['RC', 'CR', 'QM', 'KM', 'MQ', 'MK', 'cV'],
    'Vn': ['DV', 'LT', 'TL', 'nV'],
    'Vq': ['NN', 'DL', 'EV', 'LD', 'Ln', 'MP', 'PM', 'nL', 'qV'],
    'mA': ['AF', 'Am', 'DC', 'CD', 'Cn', 'MS', 'SM', 'nC'],
    'mR': ['RF', 'Rm'],
    'mN': ['NF', 'Nm', 'Tc', 'cT'],
    'mD': ['DF', 'Dm', 'MM', 'Fn', 'nF', 'nm'],
    'mC': ['CF', 'Cm'],
    'mE': ['EF', 'Em', 'Fq', 'qF', 'qm'],
    'mQ': ['Dc', 'QF', 'Qm', 'Km', 'cD', 'cn', 'nc'],
    'mG': ['CT', 'GF', 'Gm', 'TC'],
    'mH': ['HF', 'Hm'],
    'mL': ['EM', 'LF', 'Lm', 'ME', 'Mq', 'PY', 'YP', 'qM'],
    'mK': ['QF', 'Qm', 'KF', 'Km', 'FQ'],
    'mM': ['DY', 'MF', 'Mm', 'YD', 'Yn', 'nY'],
    'mF': ['MY', 'Fm', 'YM'],
    'mP': ['DE', 'Dq', 'ED', 'En', 'LM', 'ML', 'PF', 'Pm', 'nE', 'nq', 'qD', 'qn'],
    'mS': ['AY', 'CM', 'HP', 'MC', 'PH', 'SF', 'Sm', 'YA'],
    'mT': ['TF', 'Tm'],
    'mW': ['WF', 'Wm'],
    'mY': ['YF', 'Ym'],
    'mV': ['DM', 'MD', 'Mn', 'VF', 'Vm', 'nM'],
    'mm': ['MY', 'YM'],
    'mc': ['cF', 'cm'],
    'mn': ['DF', 'Dm', 'MM', 'FD', 'nF', 'nm'],
    'mq': ['EF', 'Em', 'FE', 'qF', 'qm'],
    'cA': ['Ac', 'CQ', 'CK', 'QC', 'KC'],
    'cR': ['Rc'],
    'cN': ['Nc', 'HH'],
    'cD': ['Dc', 'Qm', 'mQ', 'nc'],
    'cC': ['Cc'],
    'cE': ['CW', 'Ec', 'WC', 'qc'],
    'cQ': ['Qc', 'Kc'],
    'cG': ['NC', 'CN', 'Gc'],
    'cH': ['Hc'],
    'cL': ['Lc', 'SW', 'WS'],
    'cK': ['Qc', 'Kc'],
    'cM': ['Mc'],
    'cF': ['Fc', 'mc'],
    'cP': ['AW', 'EQ', 'QE', 'Qq', 'Pc', 'WA', 'qQ'],
    'cS': ['Sc'],
    'cT': ['NF', 'Nm', 'FN', 'Tc', 'mN'],
    'cW': ['Wc'],
    'cY': ['HW', 'yT', 'WH', 'Yc', 'Ty'],
    'cV': ['RC', 'CR', 'QM', 'KM', 'MQ', 'MK', 'Vc'],
    'cm': ['Fc', 'mc'],
    'cn': ['Dc', 'Qm', 'mQ', 'nc'],
    'cq': ['CW', 'Ec', 'WC', 'qc'],
    'nA': ['W', 'AD', 'An', 'EG', 'GE', 'Gq', 'SV', 'VS', 'qG'],
    'nR': ['RD', 'Rn'],
    'nN': ['ND', 'Nn', 'QT', 'TQ'],
    'nD': ['Dn', 'ET', 'TE', 'Tq', 'qT'],
    'nC': ['Am', 'CD', 'Cn', 'MS', 'SM', 'mA'],
    'nE': ['Dq', 'ED', 'En', 'Pm', 'mP', 'qD', 'qn'],
    'nQ': ['RS', 'NE', 'Nq', 'DK', 'EN', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'WG', 'qN'],
    'nG': ['AT', 'GD', 'Gn', 'TA'],
    'nH': ['HD', 'Hn'],
    'nL': ['NN', 'EV', 'LD', 'Ln', 'MP', 'PM', 'VE', 'Vq', 'qV'],
    'nK': ['RS', 'NE', 'Nq', 'DQ', 'EN', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'WG', 'qN'],
    'nM': ['MD', 'Mn', 'Vm', 'mV'],
    'nF': ['Dm', 'MM', 'FD', 'Fn', 'YV', 'VY', 'mD', 'mn'],
    'nP': ['PD', 'Pn'],
    'nS': ['AM', 'CV', 'MA', 'SD', 'Sn', 'TT', 'VC'],
    'nT': ['CL', 'ES', 'LC', 'SE', 'Sq', 'TD', 'Tn', 'qS'],
    'nW': ['WD', 'Wn'],
    'nY': ['MF', 'Mm', 'FM', 'YD', 'Yn', 'mM'],
    'nV': ['LT', 'TL', 'VD', 'Vn'],
    'nm': ['DF', 'MM', 'FD', 'Fn', 'mD', 'mn'],
    'nc': ['Qm', 'mQ', 'cD', 'cn'],
    'nn': ['DD', 'ET', 'TE', 'Tq', 'qT'],
    'nq': ['DE', 'ED', 'En', 'Pm', 'mP', 'qD', 'qn'],
    'qA': ['AE', 'Aq', 'CP', 'LS', 'PC', 'SL', 'TV', 'VT'],
    'qR': ['RE', 'Rq', 'WV', 'VW'],
    'qN': ['RS', 'NE', 'Nq', 'DQ', 'DK', 'QD', 'Qn', 'GW', 'KD', 'Kn', 'SR', 'WG', 'nQ', 'nK'],
    'qD': ['DE', 'Dq', 'En', 'Pm', 'mP', 'nE', 'nq'],
    'qC': ['CE', 'Cq', 'MT', 'TM'],
    'qE': ['Eq'],
    'qQ': ['AW', 'RT', 'EK', 'QE', 'Qq', 'KE', 'Kq', 'Pc', 'TR', 'WA', 'cP'],
    'qG': ['W', 'AD', 'An', 'DA', 'GE', 'Gq', 'SV', 'VS', 'nA'],
    'qH': ['CY', 'HE', 'Hq', 'YC'],
    'qL': ['NQ', 'NK', 'QN', 'LE', 'Lq', 'KN'],
    'qK': ['AW', 'RT', 'EQ', 'QE', 'Qq', 'KE', 'Kq', 'TR', 'WA'],
    'qM': ['Lm', 'ME', 'Mq', 'PY', 'YP', 'mL'],
    'qF': ['Em', 'LY', 'FE', 'Fq', 'YL', 'mE', 'mq'],
    'qP': ['PE', 'Pq'],
    'qS': ['DT', 'CL', 'LC', 'SE', 'Sq', 'TD', 'Tn', 'nT'],
    'qT': ['DD', 'Dn', 'MV', 'TE', 'Tq', 'VM', 'nD', 'nn'],
    'qW': ['WE', 'Wq'],
    'qY': ['YE', 'Yq'],
    'qV': ['NN', 'DL', 'LD', 'Ln', 'MP', 'PM', 'VE', 'Vq', 'nL'],
    'qm': ['EF', 'FE', 'Fq', 'mE', 'mq'],
    'qc': ['CW', 'WC', 'cE', 'cq'],
    'qn': ['DE', 'Dq', 'ED', 'Pm', 'mP', 'nE', 'nq'],
    'qq': ['EE'],
    'Ay': ['yA'],
    'Ry': ['yR'],
    'Ny': ['yN'],
    'Dy': ['yn', 'yD'],
    'Cy': ['yC'],
    'Ey': ['yE', 'yq'],
    'Qy': ['yK', 'yQ'],
    'Gy': ['yG'],
    'Hy': ['yH'],
    'Ly': ['yL'],
    'Ky': ['yK', 'yQ'],
    'My': ['yM'],
    'Fy': ['yF', 'ym'],
    'Py': ['yP'],
    'Sy': ['yS'],
    'Ty': ['Yc', 'yT', 'cY'],
    'Wy': ['yW'],
    'Yy': ['yY'],
    'Vy': ['yV'],
    'ny': ['yn', 'yD'],
    'qy': ['yE', 'yq'],
    'cy': ['yc'],
    'my': ['yF', 'ym'],
    'yA': ['Ay'],
    'yR': ['Ry'],
    'yN': ['Ny'],
    'yD': ['Dy', 'ny'],
    'yC': ['Cy'],
    'yE': ['Ey', 'qy'],
    'yQ': ['Ky', 'Qy'],
    'yG': ['Gy'],
    'yH': ['Hy'],
    'yL': ['Ly'],
    'yK': ['Ky', 'Qy'],
    'yM': ['My'],
    'yF': ['my', 'Fy'],
    'yP': ['Py'],
    'yS': ['Sy'],
    'yT': ['cY', 'Yc', 'Ty'],
    'yW': ['Wy'],
    'yY': ['Yy'],
    'yV': ['Vy'],
    'yn': ['Dy', 'ny'],
    'yq': ['Ey', 'qy'],
    'yc': ['cy'],
    'ym': ['my', 'Fy'],
}
